@@ -1,4 +1,4 @@
-# Copyright 2017-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2017-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,16 +10,17 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+"""Placeholder docstring"""
 from __future__ import absolute_import
 
-import pkg_resources
 import platform
 import sys
 
 import boto3
 import botocore
+import importlib_metadata
 
-SDK_VERSION = pkg_resources.require("sagemaker")[0].version
+SDK_VERSION = importlib_metadata.version("sagemaker")
 OS_NAME = platform.system() or "UnresolvedOS"
 OS_VERSION = platform.release() or "UnresolvedOSVersion"
 PYTHON_VERSION = "{}.{}.{}".format(
@@ -28,6 +29,7 @@ PYTHON_VERSION = "{}.{}.{}".format(
 
 
 def determine_prefix():
+    """Placeholder docstring"""
     prefix = "AWS-SageMaker-Python-SDK/{} Python/{} {}/{} Boto3/{} Botocore/{}".format(
         SDK_VERSION, PYTHON_VERSION, OS_NAME, OS_VERSION, boto3.__version__, botocore.__version__
     )
@@ -45,6 +47,10 @@ def determine_prefix():
 
 
 def prepend_user_agent(client):
+    """
+    Args:
+        client:
+    """
     prefix = determine_prefix()
 
     if client._client_config.user_agent is None:
